@@ -1,3 +1,4 @@
+import pytest
 from sqlalchemy_database import AsyncDatabase, Database
 
 # sqlite
@@ -17,3 +18,16 @@ async_db = AsyncDatabase.create("sqlite+aiosqlite:///amisadmin.db?check_same_thr
 
 # SQL Server
 # sync_db = Database.create('mssql+pyodbc://scott:tiger@mydsn')
+
+
+@pytest.fixture(autouse=True)
+def _setup_sync_db() -> Database:
+    yield sync_db
+    # Free connection pool resources
+    sync_db.close()  # type: ignore
+
+
+@pytest.fixture(autouse=True)
+async def _setup_async_db() -> AsyncDatabase:
+    yield async_db
+    await async_db.async_close()  # Free connection pool resources
